Welcome to pyRFtk’s documentation! — pyRFtk 2.0.0 documentation

# Welcome to pyRFtk’s documentation!

pyRFtk is an open source, EUPL-licensed Python library which can be used to build and analyse RF circuits. With it’s various modules and it’s ability to incorporate touchstone files it can be used to create and examine almost any RF-circuit imaginable.

The intended audience are experienced RF engineers or people interested in the RF circuitry field and willing to learn.

Note

The documentation is under active development

## Contents

- Tutorials
  - Installation
    - Pip
    - Source
    - Dependencies
  - Introduction
  - Touchstone files
  - Deembedding

# Indices and tables

- Index

- Module Index

- Search Page